#-*- coding: utf-8 -*-

import argparse
import configparser
import os
from sh import rsync, cp

from l2lss.utils import get_config_dir, get_date_last_commit, get_dcvs_type, concat_path, check_is_in_l2lss_repo
from l2lss.dcvsapi import Repo


def push(*sys_args):
    """Push the most recent database and files to the central server."""
    args = parse(*sys_args)
    check_is_in_l2lss_repo()
    # Get config
    config = configparser.ConfigParser()
    l2lss_folder = get_config_dir()
    path_config_file = concat_path(l2lss_folder, 'config')
    config.read(path_config_file)

    # Prepare sync folder
    date_last_commit = get_date_last_commit()
    sync_subfolder = concat_path(l2lss_folder, date_last_commit)
    if not os.path.exists(sync_subfolder):
        os.mkdir(sync_subfolder)

    # Syncs
    copy_files(config, sync_subfolder)
    dump_db(config, sync_subfolder)
    sync_folder(config, l2lss_folder)
    push_code()


def parse(*sys_args):
    """Parse the args from sys.args and returns the result."""
    parser = argparse.ArgumentParser(description='''Push the local2local_repo to the central server.''')
    args = parser.parse_args()

    return args


def copy_files(config, sync_subfolder):
    """Copy the files of the site to the sync_subfolder."""
    if 'files dir' in config['files']:
        cp(config['files']['files dir'], sync_subfolder, R=True)


def dump_db(config, sync_subfolder):
    """Dump the database to the sync_subfolder."""
    if 'dump cmd' in config['database']:
        dump_cmd = config['database']['dump cmd'].split(' ')
        dump_cmd_name = dump_cmd[0]

        # We import the command from the sh module in order to use it as a function
        _sh = __import__('sh', globals(), locals(), [dump_cmd_name], 0)
        sh_cmd = getattr(_sh, dump_cmd_name)
        dump_file = concat_path(sync_subfolder, '/db.sql')
        sh_cmd(*dump_cmd[1:], _out=dump_file)


def sync_folder(config, l2lss_folder):
    """Syncs the local l2lss_folder with the distant l2lss_folder."""
    if 'sync path' in config['path']:
        distant_folder = config['path']['sync path']
        if distant_folder[-1] != '/':
            distant_folder += '/'
        rsync(l2lss_folder + '/', distant_folder, r=True, l=True, delete=True)


def push_code():
    """Push the code using  the setup of the dcvs."""
    repo_type = get_dcvs_type()
    if repo_type:
        try:
            repo = Repo(type=repo_type)
            repo.push()
        except Exception:
            print('Repo is unable to push code. Check that your dcvs is correctly configured.')
