#-*- coding: utf-8 -*-

import os
import sys
# We need to explicitely import hg and git because we need to get the date of the last commit operation
# that is not supported by the dcvsapi.
from sh import hg, git

# Store which option goes in which category
options2sections = {'sync path': 'path',
                        'dump cmd': 'database',
                        'restore cmd': 'database',
                        'enconding': 'database',
                        'files dir': 'files',
                    }
# List of sections
sections_list = ['path', 'database', 'files']

def is_l2lss_init(path=None):
    """Return True if we are in an l2lss repo."""
    if path is None:
        path = os.getcwd()

    if path == '/':
        return False
    else:
        path_list = path.split('/')
        del path_list[-1]
        return os.path.exists(path + '/.l2lss') or is_l2lss_init('/'.join(path_list))


def get_config_dir():
    """Returns the path of the config dir. We must be sure to be in a l2lss folder."""
    path = get_root_dir()
    return path + '/.l2lss'


def get_root_dir():
    """Returns the path of the repo root directory which contains .git/ or .hg/ and .l2lss/"""
    path = os.getcwd()
    path_list = path.split('/')
    while not os.path.exists(path + '/.l2lss'):
        del path_list[-1]
        path = '/'.join(path_list)
    return path


def get_dcvs_type():
    """Returns the type of the dcvs used according to the hidden folder present in the root directory."""
    root_dir = get_root_dir()
    if os.path.exists(root_dir + '/.git'):
        return 'git'
    elif os.path.exists(root_dir + '/.hg'):
        return 'hg'


def get_date_last_commit():
    """Returns a string containing the timestamp of the last commit."""
    dcvs = get_dcvs_type()
    if dcvs == 'git':
        output = git('log', n=1, format='%at', _tty_out=False)
    elif dcvs == 'hg':
        output = hg('log', r='tip', template='{date}', _tty_out=False)
    return str(output).strip()


def concat_path(*args):
    """Concatenate a list of path by adding '/' between them if necessary."""
    args_list = list(args)
    for index, path in enumerate(args_list):
        if path[-1] == '/':
            args_list[index] = path[:-1]
        if index != 0 and path[0] == '/':
            args_list[index] = path[1:]

    return '/'.join(args_list)


def check_is_in_l2lss_repo():
    if not is_l2lss_init():
        print('You must launch this command in a l2lss repo.')
        sys.exit(1)


def get_sync_subfolder(l2lss_folder):
    """Returns the name of the lastest sync directory."""
    dirs = os.listdir(l2lss_folder)
    dirs.remove('config')
    dirs.sort()

    return dirs[-1]
