#  -*- encoding: utf-8 -*-

import unittest
import os
import shutil
import l2lss.dcvsapi as dcvsapi


class TestDcvsAPI(unittest.TestCase):
    """
        Test the dcvsapi.

        Uses and wipes folders named 'test' (a.k.a repo), 'test-clone'
        (a.k.a clone).  Tests are dependent on each other; named
        test_<number>_name for sorting.
    """
    repo_hg_path = os.getcwd() + '/test/testhg'
    repo_git_path = os.getcwd() + '/test/testgit'
    repo_hg = dcvsapi.Repo(repo_hg_path, user="testuser",  type="hg")
    repo_git = dcvsapi.Repo(repo_git_path, user="Testuser <test@example.com>",  type="git")

    @classmethod
    def _delete_and_create(cls, path):
        if os.path.exists(path):
            shutil.rmtree(path)
        os.mkdir(path)
        assert os.path.exists(path)

    def setup_class(cls):
        TestDcvsAPI._delete_and_create(TestDcvsAPI.repo_hg_path)
        TestDcvsAPI._delete_and_create(TestDcvsAPI.repo_git_path)

    def teardown_class(cls):
        shutil.rmtree("test/testhg", ignore_errors=True)
        shutil.rmtree("test/testgit",  ignore_errors=True)

    def test_10_init(self):
        print(os.getcwd())
        self.repo_git.init()
        assert os.path.exists(self.repo_git_path + '/.git')
        self.repo_hg.init()
        assert os.path.exists(self.repo_hg_path + '/.hg')

    def test_20_add(self):
        for file_name in [self.repo_hg_path + '/file', self.repo_git_path + '/file']:
            with open(file_name, 'w') as file:
                file.write('Hello World')
        self.repo_hg.add('file')
        self.repo_git.add('file')

    def test_30_commit(self):
        self.repo_hg.commit('Initial commit')
        self.repo_git.commit('Initial commit')
